.. _index:

Documentation for *species*
===========================

*species* is a toolkit for atmospheric characterization of directly imaged exoplanets.

.. toctree::
   :maxdepth: 2
   :caption: Getting Started
   :hidden:

   installation
   tutorials/running_species.ipynb

.. toctree::
   :maxdepth: 2
   :caption: User Documentation
   :hidden:

   overview
   configuration
   database
   tutorials
   modules

.. toctree::
   :maxdepth: 2
   :caption: About species
   :hidden:

   contributing
   about
